Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/__init__.py | 0 | 0 | 0 | 100%
src/auth/__init__.py | 3 | 0 | 0 | 100%
src/auth/api/__init__.py | 7 | 0 | 0 | 100%
src/auth/api/account_controller.py | 15 | 0 | 0 | 100%
src/auth/api/permission_controller.py | 28 | 0 | 0 | 100%
src/auth/api/role_controller.py | 28 | 0 | 0 | 100%
src/auth/api/user_controller.py | 31 | 0 | 0 | 100%
src/auth/factories.py | 11 | 0 | 0 | 100%
src/auth/models/__init__.py | 6 | 0 | 0 | 100%
src/auth/models/permission_model.py | 5 | 0 | 0 | 100%
src/auth/models/role_model.py | 5 | 0 | 0 | 100%
src/auth/models/role_permission_model.py | 7 | 0 | 0 | 100%
src/auth/models/user_model.py | 8 | 0 | 0 | 100%
src/auth/models/user_role_model.py | 7 | 0 | 0 | 100%
src/auth/plugin.py | 32 | 21 | 4 | 34%
src/auth/services.py | 83 | 2 | 0 | 98%
src/core/cli.py | 7 | 4 | 0 | 43%
src/core/database.py | 8 | 0 | 0 | 100%
src/core/mail.py | 20 | 13 | 0 | 35%
src/core/settings.py | 21 | 0 | 0 | 100%
Total | 332 | 40 | 4 | 88%

No items found using the specified filter.